==> glibc-2.32.tar.bz2: glibc-2.32/sysdeps/powerpc/powerpc64/multiarch/rawmemchr.c <==
/* Multiple versions of rawmemchr.
   Copyright (C) 2013-2020 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <https://www.gnu.org/licenses/>.  */

#if IS_IN (libc)
# define __rawmemchr __redirect___rawmemchr
# include <string.h>
# include <shlib-compat.h>
# include "init-arch.h"

extern __typeof (__rawmemchr) __rawmemchr_ppc attribute_hidden;
extern __typeof (__rawmemchr) __rawmemchr_power7 attribute_hidden;
# ifdef __LITTLE_ENDIAN__
extern __typeof (__rawmemchr) __rawmemchr_power9 attribute_hidden;
# endif

# undef __rawmemchr

/* Avoid DWARF definition DIE on ifunc symbol so that GDB can handle
   ifunc symbol properly.  */
libc_ifunc_redirected (__redirect___rawmemchr, __rawmemchr,
# ifdef __LITTLE_ENDIAN__
		       (hwcap2 & PPC_FEATURE2_ARCH_3_00)
		       ? __rawmemchr_power9 :
# endif
		         (hwcap & PPC_FEATURE_HAS_VSX)
		         ? __rawmemchr_power7
		       : __rawmemchr_ppc);

weak_alias (__rawmemchr, rawmemchr)
#else
#include <string/rawmemchr.c>
#endif

==> glibc-2.43.tar.bz2: glibc-2.43/sysdeps/powerpc/powerpc64/multiarch/rawmemchr.c <==
/* Multiple versions of rawmemchr.
   Copyright (C) 2013-2026 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <https://www.gnu.org/licenses/>.  */

#if IS_IN (libc)
# define __rawmemchr __redirect___rawmemchr
# include <string.h>
# include <shlib-compat.h>
# include "init-arch.h"

extern __typeof (__rawmemchr) __rawmemchr_ppc attribute_hidden;
extern __typeof (__rawmemchr) __rawmemchr_power7 attribute_hidden;
# ifdef __LITTLE_ENDIAN__
extern __typeof (__rawmemchr) __rawmemchr_power9 attribute_hidden;
extern __typeof (__rawmemchr) __rawmemchr_power10 attribute_hidden;
# endif

# undef __rawmemchr

/* Avoid DWARF definition DIE on ifunc symbol so that GDB can handle
   ifunc symbol properly.  */
libc_ifunc_redirected (__redirect___rawmemchr, __rawmemchr,
# ifdef __LITTLE_ENDIAN__
		     (hwcap2 & PPC_FEATURE2_ARCH_3_1)
		     && (hwcap & PPC_FEATURE_HAS_VSX)
		     ? __rawmemchr_power10 :
		       (hwcap2 & PPC_FEATURE2_ARCH_3_00
			&& hwcap & PPC_FEATURE_HAS_VSX)
		       ? __rawmemchr_power9 :
# endif
		         (hwcap & PPC_FEATURE_ARCH_2_06)
		         ? __rawmemchr_power7
		       : __rawmemchr_ppc);

weak_alias (__rawmemchr, rawmemchr)
#else
#include <string/rawmemchr.c>
#endif
